""" the collections of mapper functions.

@author: R. Le Gac

"""
from extjs import TabPanel


def map_default(fields):
    """Map a list of field in the C{Ext.form.formPanel}.

    @type fields: list
    @param fields: list of database field names
    
    @rtype: list
    @return: the input list
    
    """
    return fields


def map_tabpanel(fieldsets):
    """Map a list of C{FieldSets} in the C{Ext.TabPanel}.
    
        - A tab is associated to each fieldset.
        - the name of the tab is the name of the fieldset.
        
    @type fieldsets: list of FieldSet
    
    @rtype: list
    @return: the C{TapPanel} encapsulated in a list.
    
    """
    
    tabpanel = TabPanel(activeTab=0,
                        enableTabScroll=True,
                        defaults={'anchor': '98%'})
    
    for fieldset in fieldsets:
        
        title = fieldset['title']
        del fieldset['title']
        
        tab = {'border': False,
               'collapsible': False,
               'items': fieldset,
               'title': title}
        
        tabpanel.append_items(tab)

    return [tabpanel]