""" the viewport modifier.

@author: R. Le Gac

"""

from gluon.storage import Storage
from modifier import Modifier
from navtree import Node


MSG_INVALID_NODE = 'Node object is not an instance of NodeBase class.'

MODIFIER_VIEWPORTS = 'modifier_viewports'


class ViewportModifier(Modifier):
    """Modifier to customize the viewport widget of the application.
    
    """
    
    def __init__(self):
        """Initialize the viewport modifier associated to the application.
        
        The persistent data structure of the viewport modifier can be access 
        outside the class:
        
            >>> p = PluginManager('dbui')
            >>> modifier = p.dbui['modifier_viewports']
            
        or internally via the attribute C{data}.
        
        The keys of the C{data} structure are:
        
            - C{default} (list) list of C{Node.text} defining the path of the node 
            which will be opened at start up.
            
            - C{extjs} (dict) Ext JS configuration options for the viewport widget.
            
            - C{nodes} (list) list of L{Node} defining the navigation tree
        
        """
        Modifier.__init__(self, MODIFIER_VIEWPORTS)

        if 'default' not in self.data:
            self.data.default = None
        
        if 'nodes' not in self.data:
            self.data.nodes = []


    def add_node(self, *args):
        """Add L{Node}s to the navigation tree.

        @type args: L{Node}
        @param args:
        
        """
        for el in args:
            if not isinstance(el, Node):
                raise ViewportModifierException(MSG_INVALID_NODE)
        
        self.data.nodes.extend(args)


    def default_node(self, *args):
        """Defined the node which will be opened at start up.

        @type args: list of L{Node.text}
        @param args: define the path of the node
        
        """
        self.data.default = args


class ViewportModifierException(BaseException): pass
